@@ -1,8 +1,7 @@
-/*  $Id: main-window.cpp,v 1.48 2019/07/28 17:30:24 sarrazip Exp $
-    main-window.cpp - Input and conjugation window
+/*  main-window.cpp - Input and conjugation window
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2019 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2023 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -170,23 +169,21 @@ ResultPage::ResultPage()
 
 
 // Converts the given UTF-8 string to an ASCII-only string where any
-// non-ASCII character is represented by a %HH sequence where HH is
-// the 2-digit hexadecimal Unicode number of the non-ASCII character.
-// Example: "bébé" becomes "b%e9b%e9".
+// non-ASCII character is represented by a %HH%HH sequence where the
+// HH parts are 2-digit hexadecimal codes.
+// Example: "connaître" becomes "conna%c3%aetre" because character U+00EE
+// is encoded as C3 AE in UTF-8.
 //
 static string
 convertUTF8ToPercentHex(const char *utf8)
 {
     stringstream result;
     result << hex;
-    for (const char *p = utf8; *p != '\0'; p = g_utf8_next_char(p))
-    {
-        gunichar c = g_utf8_get_char(p);
-        if (c <= 127)  // if ASCII
-            result << char(c);
+    for (const unsigned char *p = (const unsigned char *) utf8; *p != '\0'; ++p)
+        if (*p <= 127)  // if ASCII
+            result << char(*p);
         else
-            result << '%' << setw(2) << c;
-    }
+            result << '%' << setw(2) << unsigned(*p);
     return result.str();
 }
 
